@@ -2,7 +2,7 @@
  * This file is part of gtatool, a tool to manipulate Generic Tagged Arrays
  * (GTAs).
  *
- * Copyright (C) 2010, 2011
+ * Copyright (C) 2010, 2011, 2013
  * Martin Lambers <marlam@marlam.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -77,9 +77,18 @@ extern "C" int gtatool_dimension_merge(int argc, char *argv[])
         }
         while (array_loops[0].read(hdris[0], nameis[0]))
         {
+            bool have_input = true;
             for (size_t i = 1; i < arguments.size(); i++)
             {
-                array_loops[i].read(hdris[i], nameis[i]);
+                if (!array_loops[i].read(hdris[i], nameis[i]))
+                {
+                    have_input = false;
+                    break;
+                }
+                if (hdris[i].data_size() == 0)
+                {
+                    throw exc(nameis[i] + ": empty array");
+                }
                 if (hdris[i].components() != hdris[0].components())
                 {
                     throw exc(nameis[i] + ": incompatible array (number of components differs)");
@@ -104,6 +113,11 @@ extern "C" int gtatool_dimension_merge(int argc, char *argv[])
                     }
                 }
             }
+            if (!have_input)
+            {
+                msg::wrn_txt("ignoring additional array(s) from %s", arguments[0].c_str());
+                break;
+            }
             gta::header hdro;
             hdro.global_taglist() = hdris[0].global_taglist();
             std::vector<uintmax_t> hdro_dim_sizes;
