@@ -222,6 +222,7 @@ private slots:
     void file_save_all();
     void file_close();
     void file_close_all();
+    void file_import();
     void file_import_csv();
     void file_import_datraw();
     void file_import_dcmtk();
@@ -240,6 +241,7 @@ private slots:
     void file_import_raw();
     void file_import_sndfile();
     void file_import_teem();
+    void file_export();
     void file_export_csv();
     void file_export_datraw();
     void file_export_exr();
@@ -256,9 +258,11 @@ private slots:
     void file_export_raw();
     void file_export_sndfile();
     void file_export_teem();
+    void stream_extract();
+    void stream_foreach();
+    void stream_grep();
     void stream_merge();
     void stream_split();
-    void stream_extract();
     void array_combine();
     void array_create();
     void array_diff();
@@ -282,6 +286,8 @@ private slots:
     void component_reorder();
     void component_set();
     void component_split();
+    void help_overview();
+    void help_website();
     void help_about();
 };
 
